﻿////////////////////////////////////////////////////////////////////////
// Модуль BatchList
////////////////////////////////////////////////////////////////////////
var BatchList = (function () {
    ///////////////////////////////////////////////////////////////////////////////
    var batchTable = null;
    ///////////////////////////////////////////////////////////////////////////////
    var BatchColumns = {
        create_date: 0,
        batch_serial: 1,
        product_gtin: 2,
        product_name: 3,
        sn_amount: 4,
        status: 5,
        status_color: 6,
        production_id: 7,
        action: 8
    };
    ///////////////////////////////////////////////////////////////////////////////
    var showHideFilter = function () {
        var show_filter = $('#show_filter').val();
        if (show_filter == 'true') {
            $('#divFilter').show();
        } else {
            $('#divFilter').hide();
        }
        loadBatchTable(null, null, null, null, null, null, null);
    };
    //////////////////////////////////////////////////////////////////////////////
    var loadBatchTable = function (batch_serial, status, filter_date, product_gtin, product_name, sn_amount, operation) {

        if (batchTable != null) {
            batchTable.api().clear();
        }

        $.fn.dataTable.moment('DD.MM.YYYY HH:mm:ss');
        var url = $("#GetListAjax").val();
        batchTable = $('#batchTable').dataTable({
            language: {
                "url": $("#lang").val()
            },
            "ajax": {
                url,
                type: "POST",
                data: {
                    batch_serial: batch_serial,
                    status: status,
                    filter_date: filter_date,
                    product_gtin: product_gtin,
                    product_name: product_name,
                    sn_amount: sn_amount,
                    operation: operation
                }
            },
            "autoWidth": false,
            "bDestroy": true,
            "bFilter": false,
            "bServerSide": true,
            "bProcessing": true,
            "order": [[0, "desc"]],
            "columnDefs": [
                {
                    "width": "120",
                    render: function (data, type, full, meta) {
                        return "<div class='text-nowrap'>" + data + "</div>";
                    },
                    targets: BatchColumns.create_date
                },
                {
                    render: function (data, type, full, meta) {
                        var status_color = full[BatchColumns.status_color];
                        return "<div class='hor-mid list-status-box " + status_color + "'>" + data + "</div>";
                    },
                    targets: BatchColumns.status
                },
                {
                    "targets": BatchColumns.production_id,
                    "visible": false,
                    "searchable": false
                },
                {
                    "targets": BatchColumns.status_color,
                    "visible": false,
                    "searchable": false
                },
                {
                    "width": "90",
                    "orderable": false,
                    "targets": -1,
                    "data": null,
                    render: function(data, type, full, meta) {

                        var url = $("#ViewUrl").val() + "/" + data[BatchColumns.action];
                        return "<div class=\"dropdown hor-mid\">" +
                            "<a href='" +
                            url +
                            "' onClick=\"window.location.href ='" +
                            url +
                            "'\" class=\"dropdown-toggle icon-box infont\" data-placement=\"bottom\" title=\"Детализация\" data-toggle=\"dropdown\">" +
                            "<i class=\"fa fa-eye table-icons-big\"></i>" +
                            "</a>" +
                            "</div>";

                    }
                }
            ]
        });
    };

    var init = function () {
        // установить формат даты для фильтра
        $("#filter_date").datepicker({
            format: 'dd.mm.yyyy',
            language: 'ru'
        });

        showHideFilter();

        $("#btnFilter").click(function () {
            if ($('#show_filter').val() == 'true') {
                $('#show_filter').val('false');
            } else {
                $('#show_filter').val('true');
            }
            showHideFilter();

            // очистить фильтр
            $('#batch_serial').val("");
            $('#filter_date').val("");
            $('#sn_amount').val("");

        });

        $("#btnApplyFilter").click(function () {
            var batch_serial = $('#batch_serial').val();
            var status = $('#status_list :selected').val();
            var filter_date = $('#filter_date').val();
            var product_gtin = $('#product_gtin').val();
            var product_name = $('#product_name').val();
            var sn_amount = $('#sn_amount').val();
            var operation = $('#operation_list :selected').val();

            loadBatchTable(batch_serial, status, filter_date, product_gtin, product_name, sn_amount, operation);
        });
    };

    return {
        init:init
    };

})();

///////////////////////////////////////////////////////////////////////////////
$(function () {

    BatchList.init();    

});