﻿////////////////////////////////////////////////////////////////////////
// Модуль BatchModal
////////////////////////////////////////////////////////////////////////
var BatchModal = (function () {
    ///////////////////////////////////////////////////////////////////////////////
    var batchTable = null;
    var batchSelectedCallBack = null;
    ///////////////////////////////////////////////////////////////////////////////
    var BatchColumns = {
        create_date: 0,
        batch_serial: 1,
        product_gtin: 2,
        product_name: 3,
        sn_amount: 4,
        status: 5,
        status_color: 6,
        production_id: 7,
        action: 8
    };
    ///////////////////////////////////////////////////////////////////////////////
    var showHideFilter = function () {
        var show_filter = $('#show_batch_filter').val();
        if (show_filter == 'true') {
            $('#divFilter').show();
        } else {
            $('#divFilter').hide();
        }
        loadRegBatchTable(null, null, null, null, null, null, null);
    };


    var getDataMatrixImage = function (id, type) {
        var url = $("#GetDataMatrixImageAjax").val();

        var result;
        $.ajax({
            url: url,
            type: "POST",
            async: false,
            data: 'id=' + id + '&type=' + type,
            dataType: 'json',
            success: function (data) {
                if (data != null && data != '') {
                    if (data.Result == true) {
                        console.info(data.Description);
                        result = data;
                    } else {
                        console.error(data.Description);
                    }
                }
            }
        });

        return result;
    }

    //////////////////////////////////////////////////////////////////////////////
    var loadRegBatchTable = function (batch_serial, status, filter_date, product_gtin, product_name, sn_amount, operation) {

        $.fn.dataTable.moment('DD.MM.YYYY HH:mm:ss');

        popUpShowProgress("#batchModal");

        $('#batchModal').modal('show');

        var url = $("#GetBatchListAjax").val();

        batchTable = $('#batchTable').dataTable({
            language: {
                "url": $("#lang").val()
            },
            "ajax": {
                url,
                type: "post",
                data: {
                    batch_serial: batch_serial,
                    status: status,
                    filter_date: filter_date,
                    product_gtin: product_gtin,
                    product_name: product_name,
                    sn_amount: sn_amount,
                    operation: operation
                },
                complete: function () {
                    $("#batchModal .modal-dialog").stop(true, true);
                    $("#batchModal .modal-dialog").animate({ "width": "1000px" }, 300, 'linear');
                    popUpShowResults("#batchModal");
                }
            },
            "bDestroy": true,
            "bFilter": false,
            "bServerSide": true,
            "bProcessing": true,
            "order": [[0, "desc"]],
            "columnDefs": [
                {
                    "width": "120",
                    render: function (data, type, full, meta) {
                        return "<div class='text-nowrap'>" + data + "</div>";
                    },
                    targets: BatchColumns.create_date
                },
                {
                    render: function (data, type, full, meta) {
                        var status_color = full[BatchColumns.status_color];
                        return "<div class='hor-mid list-status-box " + status_color + "'>" + data + "</div>";
                    },
                    targets: BatchColumns.status
                },
                {
                    "targets": BatchColumns.production_id,
                    "visible": false,
                    "searchable": false
                },
                {
                    "targets": BatchColumns.status_color,
                    "visible": false,
                    "searchable": false
                },
                {
                    "width": "90",
                    "orderable": false,
                    "targets": -1,
                    "data": null,
                    render: function (data, type, full, meta) {

                        if (StorekeeperArea) {
                            var batch_serial = data[BatchColumns.batch_serial];

                            var dataCode = getDataMatrixImage(batch_serial, "SelectItem");

                            return "<div class=\"dropdown hor-mid\">" +
                                "<button name=\"" +
                                dataCode.name +
                                "\" class=\"btn btn-stock-table-item dropdown-toggle icon-box infont\" data-placement=\"bottom\" title=\"Выбрать\" data-toggle=\"dropdown\">" +
                                "<img class=\"data-matrix-stock-table-button\" src=\"data:image/png;base64," +
                                dataCode.code +
                                "\">" +
                                "</button>" +
                                "</div>";
                        } else {
                            return "<div class=\"dropdown hor-mid\">" +
                                "<a class=\"dropdown-toggle icon-box infont\" data-placement=\"bottom\" title=\"Выбрать\" data-toggle=\"dropdown\">" +
                                "<i class=\"fa fa-hand-pointer-o table-icons-big\"></i>" +
                                "</a>" +
                                "</div>";
                        }


                    }
                }
            ]
        });

        $('#batchTable tbody').on('click', 'a, button', function () {
            var data = batchTable.api().row($(this).parents('tr')).data();

            if (batchSelectedCallBack != null)
                batchSelectedCallBack(data[BatchColumns.action])

            $('#batchModal').modal('hide');

        });
    };
    /////////////////////////////////////////////////////////////////////////////////
    var show = function () {
        showHideFilter();
    };
    /////////////////////////////////////////////////////////////////////////////////
    var init = function (callback) {

        batchSelectedCallBack = callback;

        // установить формат даты для фильтра
        $("#batch_filter_date").datepicker({
            format: 'dd.mm.yyyy',
            language: 'ru'
        });

        $('#batchModal').on('hidden.bs.modal', function () {
            popUpHideAll("#batchModal");
        });

        $('#batchModal').on('hidden.bs.modal', function () {
            $("#batchModal .modal-dialog").stop(true, true);
            $("#batchModal .modal-dialog").animate({ "width": "500px" }, 100, 'linear');
        });

        $("#btnApplyFilter").click(function () {
            var batch_serial = $('#batch_serial').val();
            var status = $('#status_list :selected').val();
            var filter_date = $('#batch_filter_date').val();
            var product_gtin = $('#product_gtin').val();
            var product_name = $('#product_name').val();
            var sn_amount = $('#sn_amount').val();
            var operation = $('#operation_list :selected').val();

            loadRegBatchTable(batch_serial, status, filter_date, product_gtin, product_name, sn_amount, operation);
        });

        $("#btnBatchFilter").click(function () {
            if ($('#show_batch_filter').val() == 'true') {
                $('#show_batch_filter').val('false');
            } else {
                $('#show_batch_filter').val('true');
            }
            showHideFilter();

            // очистить фильтр
            $('#batch_serial').val("");
            $('#filter_date').val("");
            $('#sn_amount').val("");

        });
    };

    return {
        init: init,
        show: show
    };

})();
