﻿////////////////////////////////////////////////////////////////////////
// Модуль PackageList
////////////////////////////////////////////////////////////////////////
var PackageList = (function () {
    ////////////////////////////////////////////////////////////////////////
    var snTable = null;
    //////////////////////////////////////////////////////////////////////////////
    var SnColumns = {
        create_date: 0,
        batch_serial: 1,
        serial: 2,
        product_gtin: 3,
        status_text: 4,
        status_color: 5,
        id: 6
    }
    //////////////////////////////////////////////////////////////////////////////
    var snView = function (id) {
        var url = $("#GetSnAjax").val();
        $.get(url, { id: id })
                .done(function (data) {
                    var res = false;
                    if (data !== null && data !== '') {
                        var sn = JSON.parse(data);
                        if (sn.product_gtin !== null) {
                            $('#divGTIN').html(sn.product_gtin);
                        }
                        if (sn.serial !== null) {
                            $('#divSn').html(sn.serial);
                        }
                        if (sn.batch_serial !== null) {
                            $('#divBatch').html(sn.batch_serial);
                        }
                        if (sn.product_shelf_life !== null) {
                            var now = moment();
                            var date = now.add('days', sn.product_shelf_life);
                            var sDate = date.format("YYMMDD");
                            $('#divShelfDate').html(sDate);
                        }
                        if (sn.image !== null && sn.image !== '') {
                            var oImg = document.createElement("img");
                            oImg.className = 'data-matrix-img';
                            oImg.setAttribute('src', 'data:image/png;base64,' + sn.image);
                            $("#divImage").html(oImg);
                        }
                        $('#snLabelView').modal('show');
                    }
                })
              .fail(function () {
                  $("#ordersSpinner").hide();
                  $("#ordersError").html('<h3><span class=\"error\"> Ошибка подключения </span></h3>');
                  $("#ordersError").show();
              });
    }
    /////////////////////////////////////////////////////////////////////
    var showHideFilter = function () {
        var show_filter = $('#show_filter').val();
        if (show_filter == 'true') {
            $('#divFilter').show();
        } else {
            $('#divFilter').hide();
        }

        var batch_id = $("#batch_id").val();
        loadSnTable(batch_id, null, null, null, null, null, null);

    }
    /////////////////////////////////////////////////////////////////////
    var loadSnTable = function (batch_id, batch_serial, sn, status, filter_date, product_gtin, product_name) {

        // очистить таблицу
        if (snTable != null) {
            snTable.api().clear();
        }

        $.fn.dataTable.moment('DD.MM.YYYY HH:mm:ss');
        var url = $("#GetListAjax").val();
        snTable = $('#snTable').dataTable({
            language: {
                "url": $("#lang").val()
            },
            "ajax": {
                url,
                    type: "POST",
                data: {
                    batch_id: batch_id,
                    batch_serial: batch_serial,
                    sn: sn,
                    status: status,
                    filter_date: filter_date,
                    product_gtin: product_gtin,
                    product_name: product_name
                }
            },
            "bDestroy": true,
            "bFilter": false,
            "bServerSide": true,
            "bProcessing": true,
            "order": [[0, "desc"]],
            "columnDefs": [
                {
                    "width": "120",
                    render: function (data, type, full, meta) {
                        return "<div class='text-nowrap'>" + data + "</div>";
                    },
                    targets: SnColumns.create_date
                },
                {
                    render: function (data, type, full, meta) {
                        var status_color = full[SnColumns.status_color];
                        return "<div class='hor-mid list-status-box " + status_color + "'>" + data + "</div>";
                    },
                    targets: SnColumns.status_text
                },
                {
                    "visible": false,
                    "orderable": false,
                    targets: SnColumns.status_color
                },
                {
                    "width": "90",
                    "orderable": false,
                    "targets": -1,
                    "data": null,
                    render: function (data, type, full, meta) {
                        var url = $("#viewDetailsUrl").val() + "/" + data[SnColumns.id];
                        return "<div class=\"dropdown hor-mid\">" +
                                        "<a href='" + url + "' onClick=\"window.location.href ='" + url + "'\" class=\"dropdown-toggle icon-box infont\" data-placement=\"bottom\" title=\"Детализация\" data-toggle=\"dropdown\">" +
                                            "<i class=\"fa fa-eye table-icons-big\"></i>" +
                                        "</a>" +
                                    "</div>";
                    }
                }
            ]
        });
    };

    /////////////////////////////////////////////////////////////////////////
    var onSerialNumberReceived = function (serial) {
        var url = $("#GetPackageUrlAjax").val();
        $.post(url, {
            serial: serial
        })
         .done(function (data) {
             if (data != null && data != '' && data.Result == true) {
                 window.location.href = data.url;
            }
         })
         .fail(function () {
             toastr.error("Невозможно выполнить операцию", "Ошибка!");
         });
    };
    //////////////////////////////////////////////////////////////////////////
    var init = function () {
        // установить формат даты для фильтра
        $("#filter_date").datepicker({
            format: 'dd.mm.yyyy',
            language: 'ru'
        });

        showHideFilter();

        $("#btnFilter").click(function () {
            if ($('#show_filter').val() == 'true') {
                $('#show_filter').val('false');
            } else {
                $('#show_filter').val('true');
            }
            showHideFilter();

            // очистить фильтр
            $('#batch_serial').val("");
            $('#serial').val("");
            $('#filter_date').val("");
            $('#product_gtin').val("");
            $('#product_name').val("");
        });

        $("#btnApplyFilter").click(function () {
            var batch_serial = $('#batch_serial').val();
            var sn = $('#serial').val();
            var status = $('#status_list :selected').val();
            var filter_date = $('#filter_date').val();
            var batch_id = $("#batch_id").val();
            var product_gtin = $("#product_gtin").val();
            var product_name = $("#product_name").val();

            loadSnTable(batch_id, batch_serial, sn, status, filter_date, product_gtin, product_name);
        });

        Scanner.eventSerialNumber(onSerialNumberReceived);
    };

    return {
        init:init
    };

})();
/////////////////////////////////////////////////////////////////////
$(function () {
    PackageList.init();    
});